{% extends 'django_spire/auth/page/auth_page.html' %}

{% block authentication_page_content %}
    <h5>Set Password</h5>
    <form x-data="{
        email: new GlueCharField('email', {required: true})
    }" method="POST" class="text-app-secondary">
        {% csrf_token %}
        <div class="row">
            <div class="col">
                {% include 'django_glue/form/field/char_field.html' with glue_field='email' %}
            </div>
        </div>
        <div class="row mt-2">
            <div class="col">
                <button type="submit" class="w-100 btn btn-blue mt-2">Submit</button>
            </div>
        </div>
    </form>
{% endblock %}
